
# prelims -----------------------------------------------------------------

# load libraries
library(lme4); library(MuMIn); library(optimx)

# read data file
xdata <- read.csv("babooncopulationcalls.csv", header = TRUE, sep = ",")
str(xdata)



# models ------------------------------------------------------------------

# log-transform the "number of males in the audience" to achieve a more symmetric distribution
hist(xdata$Nmales)
hist(log(xdata$Nmales + 1))
xdata$Nmales <- log(xdata$Nmales + 1)


# rescale Elo-ratings (male rank) for the males (raw values are much larger (between 600 and 2000, more than two magnitudes) in comparison to the other variables)
hist(xdata$maleElo)
xdata$maleElo <- as.numeric(scale(xdata$maleElo))


# recode two-level predictors to 0/1
xdata$lowvisib <- as.numeric(xdata$visib) - 1
xdata$swellingingroup <- as.numeric(xdata$swellingingroup) - 1
xdata$focalfullswell <- as.numeric(xdata$focalfullswell) - 1
xdata$highrankaudience <- as.numeric(xdata$highrankaudience) - 1
xdata$parous <- as.numeric(xdata$parous) - 1
xdata$matingfriend <- as.numeric(xdata$matingfriend) - 1


# build models
# sperm competition model
SC <- glmer(copcall ~ lowvisib +swellingingroup +focalfullswell +Nmales
            +(1|IDfem) +(1|IDmale)
            +(0+lowvisib|IDfem) +(0+swellingingroup|IDfem) +(0+focalfullswell|IDfem) +(0+Nmales|IDfem),
            data = xdata, family = binomial, control = glmerControl(optimizer = "optimx", optCtrl = list(method = "L-BFGS-B")))

# male-male competition model
MM <- glmer(copcall ~ lowvisib +maleElo +highrankaudience +swellingingroup +focalfullswell +Nmales +parous
            +(1|IDfem) +(1|IDmale)
            +(0+lowvisib|IDfem) +(0+maleElo|IDfem) +(0+highrankaudience|IDfem) +(0+swellingingroup|IDfem) +(0+focalfullswell|IDfem) +(0+Nmales|IDfem),
            data = xdata, family = binomial, control = glmerControl(optimizer = "optimx", optCtrl = list(method = "L-BFGS-B")))

# female choice model
FC <- glmer(copcall ~ swellingingroup +focalfullswell +Nmales +maleElo +matingfriend
            +(1|IDfem) +(1|IDmale)
            +(0+swellingingroup|IDfem) +(0+focalfullswell|IDfem) +(0+Nmales|IDfem) +(0+maleElo|IDfem) +(0+matingfriend|IDfem),
            data = xdata, family = binomial, control = glmerControl(optimizer = "optimx", optCtrl = list(method = "L-BFGS-B")))

# null model with random slopes
null <- glmer(copcall ~ 1
              +(1|IDfem) +(1|IDmale)
              +(0+swellingingroup|IDfem) +(0+focalfullswell|IDfem) +(0+Nmales|IDfem) +(0+maleElo|IDfem) +(0+matingfriend|IDfem) +(0+lowvisib|IDfem) +(0+highrankaudience|IDfem),
              data = xdata, family = binomial, control = glmerControl(optimizer = "optimx", optCtrl = list(method = "L-BFGS-B")))

res <- model.sel(SC, MM, FC, null, extra = "r.squaredGLMM")
as.data.frame(res)[, c(10, 11, 12, 14, 15, 16)]
# note this requires a relative recent developer version of the MuMIn package for the R2 calculations to work, which at the time of writing was not yet available from CRAN, but only from R-Forge using: install.packages("MuMIn", repos = "http://r-forge.r-project.org")
# the version we use here is: 1.16.6
# you can omit the R2 part to see the model ranking only:
res <- model.sel(SC, MM, FC, null)
res





# raw data figures --------------------------------------------------------

# read data again, for untransformed raw data
xdata <- read.csv("babooncopulationcalls.csv", header = TRUE, sep = ",")
str(xdata)

# uncomment next line if you want to produce a pdf of the plots
# pdf("rawdata_figure.pdf", width = 7, height = 13)

par(mfcol = c(4, 2)) # set up layout

# parous female
pdata <- data.frame(aggregate(xdata$copcall, by = list(pred = xdata$parous, fem = xdata$IDfem), sum),
                    tot = aggregate(xdata$copcall, by= list(pred = xdata$parous, fem = xdata$IDfem), length)[, 3])
cols <- grey.colors(5, alpha = 0.8)

plot(0, 0, "n", xlim = c(0.5, 2.5), ylim = c(0, 1), axes = F, xlab = "female parity", ylab = "proportion of copulations with calls")
points(as.numeric(as.factor(pdata$pred)), pdata$x/pdata$tot, pch = 16, col = cols)

axis(1, at = c(1, 2), labels = c("nulliparous", "parous"), tcl = 0); axis(2, las = 1, tcl = 0.3); box()
legend("topleft", legend = "", bty = "n", title = "(a)")


# male Elo
plot(0, 0, "n", xlim = c(650, 1270), ylim = c(0, 1), axes = F, xlab = "male Elo-rating", ylab = "proportion of copulations with calls")
cols <- grey.colors(5, alpha = 0.8); COL <- 1

for(i in unique(xdata$IDfem)) {
  temp <- xdata[xdata$IDfem == i, ]
  pdata <- data.frame(aggregate(temp$copcall, by = list(pred = temp$maleElo, fem = temp$IDfem), sum),
                      tot = aggregate(temp$copcall, by = list(pred = temp$maleElo, fem = temp$IDfem), length)[, 3])
  points(pdata$pred, pdata$x/pdata$tot, pch = 16, type = "b", col = cols[COL])
  COL <- COL + 1
}

axis(1, tcl = 0.3); axis(2, las = 1, tcl = 0.3); box()
legend("topleft", legend = "", bty = "n", title = "(c)")



# male friend
plot(0, 0, "n", xlim = c(0.5, 2.5), ylim = c(0,1), axes = F, xlab = "mating partner is friend", ylab = "proportion of copulations with calls")
cols <- grey.colors(5, alpha = 0.8); COL <- 1

for(i in unique(xdata$IDfem)) {
  temp <- xdata[xdata$IDfem == i, ]
  pdata <- data.frame(aggregate(temp$copcall, by = list(pred=temp$matingfriend), sum),
                      tot = aggregate(temp$copcall, by = list(pred = temp$matingfriend), length)[, 2])
  points(as.numeric(pdata$pred), pdata$x/pdata$tot, pch = 16, type = "b", col = cols[COL])
  COL <- COL + 1
}

axis(1, at = c(1,2), labels = c("non-friend partner", "friend partner"), tcl = 0); axis(2, las = 1, tcl = 0.3); box()
legend("topleft", legend = "", bty = "n", title = "(e)")


# male audience size
plot(0, 0, "n", xlim = range(xdata$Nmales), ylim = c(0, 1), axes = F, xlab = bquote(paste(italic("N"), plain(" males in audience"))), ylab = "proportion of copulations with calls")
cols <- grey.colors(5, alpha = 0.8); COL <- 1

for(i in unique(xdata$IDfem)) {
  temp <- xdata[xdata$IDfem == i, ]
  pdata <- data.frame(aggregate(temp$copcall, by = list(pred = temp$Nmales, fem = temp$IDfem), sum),
                      tot = aggregate(temp$copcall, by = list(pred = temp$Nmales, fem = temp$IDfem), length)[, 3])
  points(pdata$pred, pdata$x/pdata$tot, pch = 16, type = "b", col = cols[COL], lwd = 0.5)
  COL <- COL + 1
}

axis(1, tcl = 0.3); axis(2, las = 1, tcl = 0.3); box()
legend("topleft", legend = "", bty = "n", title = "(g)")

# at least one high-rated male in audience
plot(0, 0, "n", xlim = c(0.5, 2.5), ylim = c(0, 1), axes = F, xlab = "at least one high-ranking male in audience", ylab = "proportion of copulations with calls")
cols <- grey.colors(5, alpha = 0.8); COL <- 1

for(i in unique(xdata$IDfem)) {
  temp <- xdata[xdata$IDfem == i, ]
  pdata <- data.frame(aggregate(temp$copcall, by = list(pred = temp$highrankaudience), sum),
                      tot = aggregate(temp$copcall, by = list(pred = temp$highrankaudience), length)[, 2])
  points(as.numeric(pdata$pred), pdata$x/pdata$tot, pch = 16, type = "b", col = cols[COL])
  COL <- COL + 1
}

axis(1, at = c(1,2), labels = c("no", "yes"), tcl = 0); axis(2, las = 1, tcl = 0.3); box()
legend("topleft", legend = "", bty = "n", title = "(b)")


# female swollen
plot(0, 0, "n", xlim = c(0.5, 2.5), ylim = c(0,1), axes = F, xlab = "focal female fully swollen", ylab = "proportion of copulations with calls")
cols <- grey.colors(5, alpha = 0.8); COL <- 1

for(i in unique(xdata$IDfem)) {
  temp <- xdata[xdata$IDfem == i, ]
  pdata <- data.frame(aggregate(temp$copcall, by = list(pred = temp$focalfullswell), sum),
                      tot = aggregate(temp$copcall, by = list(pred = temp$focalfullswell), length)[, 2])
  points(as.numeric(pdata$pred), pdata$x/pdata$tot, pch = 16, type = "b", col = cols[COL])
  COL <- COL + 1
}

axis(1, at = c(1,2), labels = c("no", "yes"), tcl = 0); axis(2, las = 1, tcl = 0.3); box()
legend("topleft", legend = "", bty = "n", title = "(d)")


# at least one other fully swollen female in troop
plot(0, 0, "n", xlim = c(0.5, 2.5), ylim = c(0,1), axes = F, xlab = "at least one other swollen female in troop", ylab = "proportion of copulations with calls")
cols <- grey.colors(5, alpha = 0.8); COL <- 1

for(i in unique(xdata$IDfem)) {
  temp <- xdata[xdata$IDfem == i, ]
  pdata <- data.frame(aggregate(temp$copcall, by = list(pred = temp$swellingingroup), sum),
                      tot = aggregate(temp$copcall, by = list(pred = temp$swellingingroup), length)[, 2])
  points(as.numeric(pdata$pred), pdata$x/pdata$tot, pch = 16, type = "b", col = cols[COL])
  COL <- COL + 1
}

axis(1, at = c(1,2), labels = c("no", "yes"), tcl = 0); axis(2, las = 1, tcl = 0.3); box()
legend("topleft", legend = "", bty = "n", title = "(f)")

# Habitat visibility
plot(0, 0, "n", xlim = c(0.5, 2.5), ylim = c(0,1), axes = F, xlab = "habitat visibility", ylab = "proportion of copulations with calls")
cols <- grey.colors(5, alpha = 0.8); COL <- 1

for(i in unique(xdata$IDfem)) {
  temp <- xdata[xdata$IDfem == i, ]
  pdata <- data.frame(aggregate(temp$copcall, by = list(pred = temp$visib), sum),
                      tot = aggregate(temp$copcall, by = list(pred = temp$visib), length)[, 2])
  points(as.numeric(pdata$pred), pdata$x/pdata$tot, pch = 16, type = "b", col = cols[COL])
  COL <- COL + 1
}

axis(1, at = c(1,2), labels = c("high", "low"), tcl = 0); axis(2, las = 1, tcl = 0.3); box();
legend("topleft", legend = "", bty = "n", title = "(h)")

dev.off() # 'finalize' the pdf if needed

